@@ -231,6 +231,7 @@ class CmdInterface:
         """
         CmdInterface.__autocommit_mainfile_repo = do_autocommit
         CmdInterface.__autocommit_mainfile_repo_done = False
+        CmdInterface.__auto_add_repo_path()
 
     @staticmethod
     def __auto_add_repo_path():
@@ -479,11 +480,14 @@ class CmdInterface:
             CmdInterface.__run_id = str(uuid.uuid4())
 
         tar = None
+        packed_files = []
         if CmdInterface.__pack_source_files:
             tar = tarfile.open(CmdInterface.__logfile_name.replace('.json', '_' + CmdInterface.__run_id + '.tar'), "a")
+            packed_files = tar.getnames()
+            for i in range(len(packed_files)):
+                packed_files[i] = '/' + packed_files[i]
 
         self.__log['call_stack'] = list()
-        packed_files = []
         for frame in inspect.stack()[1:]:
             el = dict()
             el['file'] = os.path.abspath(str(frame[1]))
@@ -491,7 +495,7 @@ class CmdInterface:
             el['function'] = str(frame[3])
             self.__log['call_stack'].append(el)
 
-            if tar is not None and not el['file'].__contains__('site-packages') and not el['file'] in packed_files:
+            if tar is not None and not el['file'].__contains__('site-packages') and el['file'] not in packed_files:
                 packed_files.append(el['file'])
                 file_name = os.path.basename(el['file'])
                 if file_name != 'CmdInterface.py':
@@ -1092,3 +1096,4 @@ class CmdInterface:
                 exit()
 
         return return_code
+
